pub enum DefuzzificationOp {
Cog,
Boa,
Mom,
Lom,
Som,
}Expand description
Method for defuzzifcating the resulting membership function.
Variants
Cog
Center of Gravity
Boa
Bisector of Area
Mom
Mean of the values for which the membership function is maximum
Lom
Largest value for which the membership function is maximum
Som
Smallest value for which the membership function is minimum
Implementations